@@ -1,31 +1,27 @@
 /*
  *  agShell
- *  $Id: agShell.c,v 4.18 2006/10/06 05:29:00 bkorb Exp $
+ *  $Id: agShell.c,v 4.21 2007/07/04 20:51:10 bkorb Exp $
  *
- *  Time-stamp:        "2006-10-05 21:50:48 bkorb"
- *  Last Committed:    $Date: 2006/10/06 05:29:00 $
+ *  Time-stamp:        "2007-07-04 11:14:29 bkorb"
+ *  Last Committed:    $Date: 2007/07/04 20:51:10 $
  *
  *  Manage a server shell process
- */
-
-/*
- *  AutoGen copyright 1992-2006 Bruce Korb
  *
- *  AutoGen is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoGen.
+ *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
  *
- *  AutoGen is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * AutoGen is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with AutoGen.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ * AutoGen is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef SHELL_ENABLED
@@ -136,11 +132,11 @@ serverSetup( void )
     {
         static int doneOnce = 0;
         if (doneOnce++ == 0) {
-            char* p = malloc( MAXPATHLEN );
+            char* p = malloc( AG_PATH_MAX );
             if (p == NULL)
                 AG_ABEND( "cannot allocate path name" );
 
-            pCurDir = (tpChar)getcwd( p, MAXPATHLEN );
+            pCurDir = (tpChar)getcwd( p, AG_PATH_MAX );
 
             if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL)
                 fputs( "\nServer First Start\n", pfTrace );
@@ -347,7 +343,7 @@ chainOpen( int       stdinFd,
      *  Make the output file unbuffered only.
      *  We do not want to wait for shell output buffering.
      */
-    setvbuf( stdout, NULL, _IONBF, 0 );
+    setvbuf(stdout, NULL, _IONBF, (size_t)0);
 
     if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL) {
         fprintf( pfTrace, "Server shell %s starts\n", pzShell );
@@ -448,7 +444,7 @@ loadData( void )
          *  at all and we should.  Retry in those cases (but not on EOF).
          */
         alarm( (unsigned int)OPT_VALUE_TIMEOUT );
-        line_p = fgets( zLine, sizeof( zLine ), serverPair.pfRead );
+        line_p = fgets(zLine, (int)sizeof(zLine), serverPair.pfRead);
         alarm( 0 );
 
         if (line_p == NULL) {
@@ -516,7 +512,7 @@ loadData( void )
     if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL) {
         fprintf( pfTrace, "\n= = = RESULT %d bytes:\n%s%s\n"
                  "= = = = = = = = = = = = = = =\n",
-                 textSize, pzText, zLine );
+                 (int)textSize, pzText, zLine );
     }
 
     *pzScan  = NUL;
