@@ -1,32 +1,28 @@
 
 /*
  *  autogen.c
- *  $Id: autogen.c,v 4.20 2007/02/04 22:17:39 bkorb Exp $
+ *  $Id: autogen.c,v 4.23 2007/07/28 17:59:16 bkorb Exp $
  *
- *  Time-stamp:        "2007-02-04 08:28:43 bkorb"
- *  Last Committed:    $Date: 2007/02/04 22:17:39 $
+ *  Time-stamp:        "2007-07-22 09:00:32 bkorb"
+ *  Last Committed:    $Date: 2007/07/28 17:59:16 $
  *
  *  This is the main routine for autogen.
- */
-
-/*
- *  AutoGen copyright 1992-2007 Bruce Korb
  *
- *  AutoGen is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoGen.
+ *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
  *
- *  AutoGen is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * AutoGen is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with AutoGen.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ * AutoGen is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 tSCC zClientInput[] = "client-input";
@@ -427,6 +423,13 @@ signalSetup( sighandler_proc_t* chldHandler,
              */
         case SIGKILL:
         case SIGSTOP:
+
+            /*
+             *  Signals we choose to leave alone.
+             */
+#ifdef SIGTSTP
+        case SIGTSTP:
+#endif
             continue;
 
 #if defined(DEBUG_ENABLED)
@@ -447,9 +450,6 @@ signalSetup( sighandler_proc_t* chldHandler,
 #ifdef SIGWINCH
         case SIGWINCH:
 #endif
-#ifdef SIGTSTP
-        case SIGTSTP:  /* suspended  */
-#endif
 #ifdef SIGTTIN
         case SIGTTIN:  /* tty input  */
 #endif
@@ -490,7 +490,7 @@ ao_malloc (size_t sz)
 {
     void * res = malloc(sz);
     if (res == NULL) {
-        fprintf(stderr, "malloc of %d bytes failed\n", (int)sz);
+        fprintf(stderr, "malloc of %zd bytes failed\n", sz);
         exit( EXIT_FAILURE );
     }
     return res;
@@ -502,7 +502,7 @@ ao_realloc (void *p, size_t sz)
 {
     void * res = realloc(p, sz);
     if (res == NULL) {
-        fprintf(stderr, "realloc of %d bytes at 0x%p failed\n", (int)sz, p);
+        fprintf(stderr, "realloc of %zd bytes at 0x%p failed\n", sz, p);
         exit( EXIT_FAILURE );
     }
     return res;
