@@ -1,52 +1,29 @@
 
 /*
- *  sort.c  $Id: sort.c,v 4.7 2006/06/24 23:36:08 bkorb Exp $
- * Time-stamp:      "2006-06-24 10:53:35 bkorb"
+ *  sort.c  $Id: sort.c,v 4.12 2007/07/04 21:36:38 bkorb Exp $
+ * Time-stamp:      "2007-07-04 11:34:52 bkorb"
  *
  *  This module implements argument sorting.
- */
-
-/*
- *  Automated Options copyright 1992-2006 Bruce Korb
  *
- *  Automated Options is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoOpts, a companion to AutoGen.
+ *  AutoOpts is free software.
+ *  AutoOpts is copyright (c) 1992-2007 by Bruce Korb - all rights reserved
  *
- *  Automated Options is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  AutoOpts is available under any one of two licenses.  The license
+ *  in use must be one of these two and the choice is under the control
+ *  of the user of the license.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with Automated Options.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ *   The GNU Lesser General Public License, version 3 or later
+ *      See the files "COPYING.lgplv3" and "COPYING.gplv3"
  *
- * As a special exception, Bruce Korb gives permission for additional
- * uses of the text contained in his release of AutoOpts.
+ *   The Modified Berkeley Software Distribution License
+ *      See the file "COPYING.mbsd"
  *
- * The exception is that, if you link the AutoOpts library with other
- * files to produce an executable, this does not by itself cause the
- * resulting executable to be covered by the GNU General Public License.
- * Your use of that executable is in no way restricted on account of
- * linking the AutoOpts library code into it.
+ *  These files have the following md5sums:
  *
- * This exception does not however invalidate any other reasons why
- * the executable file might be covered by the GNU General Public License.
- *
- * This exception applies only to the code released by Bruce Korb under
- * the name AutoOpts.  If you copy code from other sources under the
- * General Public License into a copy of AutoOpts, as the General Public
- * License permits, the exception does not apply to the code that you add
- * in this way.  To avoid misleading anyone as to the status of such
- * modified files, you must delete this exception notice from them.
- *
- * If you write modifications of your own for AutoOpts, it is your choice
- * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.
+ *  239588c55c22c60ffe159946a760a33e pkg/libopts/COPYING.gplv3
+ *  fa82ca978890795162346e661b47161a pkg/libopts/COPYING.lgplv3
+ *  66a5cedaf62c4b2637025f049f9b826f pkg/libopts/COPYING.mbsd
  */
 
 /* = = = START-STATIC-FORWARD = = = */
@@ -210,19 +187,10 @@ optionSort( tOptions* pOpts )
     tOptState os = OPTSTATE_INITIALIZER(DEFINED);
 
     /*
-     *  Disable for POSIX conformance
+     *  Disable for POSIX conformance, or if there are no operands.
      */
-    if (getenv( "POSIXLY_CORRECT" ) != NULL) {
-        errno = 0;
-        return;
-    }
-
-    errno = ENOENT;
-
-    /*
-     *  If all arguments are named, we can't sort 'em.  There are no operands.
-     */
-    if (NAMED_OPTS(pOpts))
+    if (  (getenv( "POSIXLY_CORRECT" ) != NULL)
+       || NAMED_OPTS(pOpts))
         return;
 
     /*
@@ -268,7 +236,7 @@ optionSort( tOptions* pOpts )
         switch (pzArg[1]) {
         case NUL:
             /*
-             *  A regular option.  Put it on the operand list.
+             *  A single hyphen is an operand.
              */
             ppzOpds[ opdsIdx++ ] = pOpts->origArgVect[ (pOpts->curOptIdx)++ ];
             continue;
@@ -300,7 +268,7 @@ optionSort( tOptions* pOpts )
             break;
         }
         if (FAILED( res )) {
-            errno = EIO;
+            errno = EINVAL;
             goto freeTemps;
         }
 
@@ -320,7 +288,7 @@ optionSort( tOptions* pOpts )
             if (  (os.optType == TOPT_SHORT)
                && FAILED( checkShortOpts( pOpts, pzArg+2, &os,
                                           ppzOpts, &optsIdx )) )  {
-                errno = EIO;
+                errno = EINVAL;
                 goto freeTemps;
             }
 
@@ -363,7 +331,6 @@ optionSort( tOptions* pOpts )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of autoopts/sort.c */
