@@ -1,24 +1,28 @@
 /*
  *  This file defines the string_tokenize interface
+ * Time-stamp:      "2007-07-04 10:09:43 bkorb"
  *
- *  string_tokenize copyright 2005 Bruce Korb
+ *  This file is part of AutoOpts, a companion to AutoGen.
+ *  AutoOpts is free software.
+ *  AutoOpts is copyright (c) 1992-2007 by Bruce Korb - all rights reserved
  *
- *  string_tokenize is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) any later version.
- *  
- *  string_tokenize is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
- *  
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with string_tokenize; if not, write to:
- *             The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *  AutoOpts is available under any one of two licenses.  The license
+ *  in use must be one of these two and the choice is under the control
+ *  of the user of the license.
+ *
+ *   The GNU Lesser General Public License, version 3 or later
+ *      See the files "COPYING.lgplv3" and "COPYING.gplv3"
+ *
+ *   The Modified Berkeley Software Distribution License
+ *      See the file "COPYING.mbsd"
+ *
+ *  These files have the following md5sums:
+ *
+ *  239588c55c22c60ffe159946a760a33e pkg/libopts/COPYING.gplv3
+ *  fa82ca978890795162346e661b47161a pkg/libopts/COPYING.lgplv3
+ *  66a5cedaf62c4b2637025f049f9b826f pkg/libopts/COPYING.mbsd
  */
+
 #include <ctype.h>
 #include <errno.h>
 #include <stdlib.h>
@@ -29,14 +33,14 @@
 /* = = = START-STATIC-FORWARD = = = */
 /* static forward declarations maintained by :mkfwd */
 static void
-copy_cooked( ch_t** ppDest, cc_t** ppSrc );
+copy_cooked( ch_t** ppDest, char const ** ppSrc );
 
 static void
-copy_raw( ch_t** ppDest, cc_t** ppSrc );
+copy_raw( ch_t** ppDest, char const ** ppSrc );
 /* = = = END-STATIC-FORWARD = = = */
 
 static void
-copy_cooked( ch_t** ppDest, cc_t** ppSrc )
+copy_cooked( ch_t** ppDest, char const ** ppSrc )
 {
     ch_t* pDest = (ch_t*)*ppDest;
     const ch_t* pSrc  = (const ch_t*)(*ppSrc + 1);
@@ -44,87 +48,12 @@ copy_cooked( ch_t** ppDest, cc_t** ppSrc )
     for (;;) {
         ch_t ch = *(pSrc++);
         switch (ch) {
-        case NUL:   pSrc--; /* FALLTHROUGH */
+        case NUL:   *ppSrc = NULL; return;
         case '"':   goto done;
         case '\\':
-            switch (*pSrc) {
-            case '0':
-            case '1':
-            case '2':
-            case '3':
-                /*
-                 *  One, two or three octal digits
-                 */
-                ch = (*(pSrc++)) - '0';
-                if (! isdigit( *pSrc ))
-                    break;
-                if (*pSrc >= '8')
-                    break;
-                ch = (ch << 3) + (*(pSrc++)) - '0';
-                if (! isdigit( *pSrc ))
-                    break;
-                if (*pSrc >= '8')
-                    break;
-                ch = (ch << 3) + (*(pSrc++)) - '0';
+            pSrc += ao_string_cook_escape_char( (char*)pSrc, (char*)&ch, 0x7F );
+            if (ch == 0x7F)
                 break;
-
-            case '4':
-            case '5':
-            case '6':
-            case '7':
-                /*
-                 *  One or two octal digits
-                 */
-                ch = (*(pSrc++)) - '0';
-                if (! isdigit( *pSrc ))
-                    break;
-                if (*pSrc >= '8')
-                    break;
-                ch = (ch << 3) + (*(pSrc++)) - '0';
-                break;
-
-            case 'x':
-                if (! isxdigit( *++pSrc )) {
-                    ch = 'x';
-                    break;
-                }
-                {
-                    ch_t chars[4];
-                    chars[0] = *(pSrc++);
-                    if (isxdigit( *pSrc )) {
-                        chars[1] = *(pSrc++);
-                        chars[2] = NUL;
-                    } else {
-                        chars[1] = NUL;
-                    }
-                    ch = (ch_t)strtol( (char*)chars, NULL, 16 );
-                }
-                break;
-
-            case '\r':
-                if (*(++pSrc) == '\n')
-                    ++pSrc;
-                continue;
-
-            case '\n':
-                ++pSrc;
-                continue;
-
-            case 'f': ch = '\f'; pSrc++; break;
-            case 'n': ch = '\n'; pSrc++; break;
-            case 'r': ch = '\r'; pSrc++; break;
-            case 't': ch = '\t'; pSrc++; break;
-            case 'v': ch = '\v'; pSrc++; break;
-            case 'b': ch = '\b'; pSrc++; break;
-            case 'a': ch = '\a'; pSrc++; break;
-
-            case NUL:
-                break;
-
-            default:
-                ch = *(pSrc++);
-                break;
-            }
             /* FALLTHROUGH */
 
         default:
@@ -134,20 +63,20 @@ copy_cooked( ch_t** ppDest, cc_t** ppSrc )
 
  done:
     *ppDest = (ch_t*)pDest; /* next spot for storing character */
-    *ppSrc  = (ch_t*)pSrc;  /* char following closing quote    */
+    *ppSrc  = (char const *)pSrc;  /* char following closing quote    */
 }
 
 
 static void
-copy_raw( ch_t** ppDest, cc_t** ppSrc )
+copy_raw( ch_t** ppDest, char const ** ppSrc )
 {
     ch_t* pDest = *ppDest;
-    cc_t* pSrc  = *ppSrc + 1;
+    cc_t* pSrc  = (cc_t*) (*ppSrc + 1);
 
     for (;;) {
         ch_t ch = *(pSrc++);
         switch (ch) {
-        case NUL:   pSrc--; /* FALLTHROUGH */
+        case NUL:   *ppSrc = NULL; return;
         case '\'':  goto done;
         case '\\':
             /*
@@ -155,6 +84,7 @@ copy_raw( ch_t** ppDest, cc_t** ppSrc )
              *  quoting and apostrophe quoting
              */
             switch (*pSrc) {
+            case NUL:   *ppSrc = NULL; return;
             case '\r':
                 if (*(++pSrc) == '\n')
                     ++pSrc;
@@ -181,15 +111,15 @@ copy_raw( ch_t** ppDest, cc_t** ppSrc )
 
  done:
     *ppDest = pDest; /* next spot for storing character */
-    *ppSrc  = pSrc;  /* char following closing quote    */
+    *ppSrc  = (char const *) pSrc;  /* char following closing quote    */
 }
 
 
-/*=export_func string_tokenize
+/*=export_func ao_string_tokenize
  *
- * what: this is the main option processing routine
+ * what: tokenize an input string
  *
- * arg:  + const char* + string + string to be tokenized +
+ * arg:  + char const* + string + string to be tokenized +
  *
  * ret_type:  token_list_t*
  * ret_desc:  pointer to a structure that lists each token
@@ -202,10 +132,23 @@ copy_raw( ch_t** ppDest, cc_t** ppSrc )
  * or double quote characters, then the text after that character up to
  * a matching quote will become the string in the list.
  *
+ *  The returned pointer should be deallocated with @code{free(3C)} when
+ *  are done using the data.  The data are placed in a single block of
+ *  allocated memory.  Do not deallocate individual token/strings.
+ *
+ *  The structure pointed to will contain at least these two fields:
+ *  @table @samp
+ *  @item tkn_ct
+ *  The number of tokens found in the input string.
+ *  @item tok_list
+ *  An array of @code{tkn_ct + 1} pointers to substring tokens, with
+ *  the last pointer set to NULL.
+ *  @end table
+ *
  * There are two types of quoted strings: single quoted (@code{'}) and
  * double quoted (@code{"}).  Singly quoted strings are fairly raw in that
  * escape characters (@code{\\}) are simply another character, except when
- * preceeding the following characters:
+ * preceding the following characters:
  * @example
  * @code{\\}  double backslashes reduce to one
  * @code{'}   incorporates the single quote into the string
@@ -219,21 +162,26 @@ copy_raw( ch_t** ppDest, cc_t** ppSrc )
  * @example
  *    #include <stdlib.h>
  *    int ix;
- *    token_list_t* ptl = string_tokenize( some_string )
+ *    token_list_t* ptl = ao_string_tokenize( some_string )
  *    for (ix = 0; ix < ptl->tkn_ct; ix++)
  *       do_something_with_tkn( ptl->tkn_list[ix] );
  *    free( ptl );
  * @end example
  * Note that everything is freed with the one call to @code{free(3C)}.
  *
- * err:  NULL is returned and @code{errno} will be set to indicate the problem:
- * @example
- * ENOENT if the input string contains nothing.
- * ENOMEM if there is not enough memory.
- * @end example
+ * err:
+ *  NULL is returned and @code{errno} will be set to indicate the problem:
+ *  @itemize @bullet
+ *  @item
+ *  @code{EINVAL} - There was an unterminated quoted string.
+ *  @item
+ *  @code{ENOENT} - The input string was empty.
+ *  @item
+ *  @code{ENOMEM} - There is not enough memory.
+ *  @end itemize
 =*/
 token_list_t*
-string_tokenize( const char* str )
+ao_string_tokenize( char const* str )
 {
     int max_token_ct = 1; /* allow for trailing NUL on string */
     token_list_t* res;
@@ -244,7 +192,7 @@ string_tokenize( const char* str )
      *  Trim leading white space.  Use "ENOENT" and a NULL return to indicate
      *  an empty string was passed.
      */
-    while (isspace( *str ))  str++;
+    while (isspace( (ch_t)*str ))  str++;
     if (*str == NUL) {
     bogus_str:
         errno = ENOENT;
@@ -286,23 +234,33 @@ string_tokenize( const char* str )
         do  {
             res->tkn_list[ res->tkn_ct++ ] = pzDest;
             for (;;) {
-                char ch = *str;
+                int ch = (ch_t)*str;
                 if (isspace( ch )) {
                 found_white_space:
-                    while (isspace( *++str ))  ;
+                    while (isspace( (ch_t)*++str ))  ;
                     break;
                 }
 
                 switch (ch) {
                 case '"':
-                    copy_cooked( &pzDest, (cc_t**)&str );
-                    if (isspace( *str ))
+                    copy_cooked( &pzDest, &str );
+                    if (str == NULL) {
+                        free(res);
+                        errno = EINVAL;
+                        return NULL;
+                    }
+                    if (isspace( (ch_t)*str ))
                         goto found_white_space;
                     break;
 
                 case '\'':
-                    copy_raw( &pzDest, (cc_t**)&str );
-                    if (isspace( *str ))
+                    copy_raw( &pzDest, &str );
+                    if (str == NULL) {
+                        free(res);
+                        errno = EINVAL;
+                        return NULL;
+                    }
+                    if (isspace( (ch_t)*str ))
                         goto found_white_space;
                     break;
 
@@ -340,7 +298,7 @@ main( int argc, char** argv )
     }
     while (--argc > 0) {
         char* arg = *(++argv);
-        token_list_t* p = string_tokenize( arg );
+        token_list_t* p = ao_string_tokenize( arg );
         if (p == NULL) {
             printf( "Parsing string ``%s'' failed:\n\terrno %d (%s)\n",
                     arg, errno, strerror( errno ));
@@ -361,7 +319,6 @@ main( int argc, char** argv )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of agen5/autogen.c */
+ * end of autoopts/tokenize.c */
